# AutomationScript

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**arguments** | [**list[Argument]**](Argument.md) |  | [optional] 
**comment** | **str** |  | [optional] 
**commit_message** | **str** |  | [optional] 
**context_keys** | **list[str]** |  | [optional] 
**depends_on** | **dict(str, list[str])** | This fields indicates which commands this script depends on | [optional] 
**deprecated** | **bool** |  | [optional] 
**docker_image** | **str** |  | [optional] 
**enabled** | **bool** |  | [optional] 
**has_role** | **bool** | Internal field to make queries on role faster | [optional] 
**hidden** | **bool** |  | [optional] 
**id** | **str** |  | [optional] 
**important** | [**list[Important]**](Important.md) |  | [optional] 
**locked** | **bool** |  | [optional] 
**modified** | **datetime** |  | [optional] 
**name** | **str** |  | [optional] 
**outputs** | [**list[Output]**](Output.md) |  | [optional] 
**prev_name** | **str** |  | [optional] 
**previous_roles** | **list[str]** | PreviousRoleName - do not change this field manually | [optional] 
**pswd** | **str** |  | [optional] 
**raw_tags** | **list[str]** |  | [optional] 
**roles** | **list[str]** | The role assigned to this investigation | [optional] 
**run_as** | **str** |  | [optional] 
**run_once** | **bool** |  | [optional] 
**script** | **str** |  | [optional] 
**script_target** | [**ScriptTarget**](ScriptTarget.md) |  | [optional] 
**searchable_name** | **str** |  | [optional] 
**sensitive** | **bool** |  | [optional] 
**should_commit** | **bool** |  | [optional] 
**sort_values** | **list[str]** |  | [optional] 
**subtype** | [**ScriptSubType**](ScriptSubType.md) |  | [optional] 
**system** | **bool** |  | [optional] 
**tags** | **list[str]** |  | [optional] 
**timeout** | [**Duration**](Duration.md) |  | [optional] 
**type** | [**ScriptType**](ScriptType.md) |  | [optional] 
**user** | **str** |  | [optional] 
**vc_should_ignore** | **bool** |  | [optional] 
**version** | **int** |  | [optional] 
**visual_script** | **str** |  | [optional] 

[[Back to Model list]](README.md#documentation-for-models) [[Back to API list]](README.md#documentation-for-api-endpoints) [[Back to README]](README.md)


